@@ -1254,7 +1254,7 @@ days since 2000-1-1
             calendar_years=calendar_years,
             i=True)
 
-        if c._hasbounds:
+        if c.hasbounds:
             c.bounds.convert_reference_time(units=units,
                                             calendar_months=calendar_months,
                                             calendar_years=calendar_years,
@@ -1315,7 +1315,7 @@ days since 2000-1-1
 #
 #        super(BoundedVariable, c).cos(i=True)
 #
-#        if c._hasbounds:
+#        if c.hasbounds:
 #            c.bounds.cos(i=True)
 #
 #        return c
@@ -1781,6 +1781,53 @@ keyword. Bounds may also be inserted independently with the
         self._direction = None
     #--- End: def
 
+    def override_calendar(self, calendar, i=False):
+        '''Override the calendar of date-time units.
+
+The new calendar **need not** be equivalent to the original one and
+the data array elements will not be changed to reflect the new
+units. Therefore, this method should only be used when it is known
+that the data array values are correct but the calendar has been
+incorrectly encoded.
+
+Not to be confused with setting the `calendar` or `Units` attributes
+to a calendar which is equivalent to the original calendar
+
+.. seealso:: `calendar`, `override_units`, `units`, `Units`
+
+.. versionadded:: 2.1.14
+
+:Examples 1:
+
+>>> g = f.{+name}('noleap')
+
+:Parameters:
+
+    calendar: `str`
+        The new calendar.
+
+    {+i}
+
+:Returns:
+
+    out: `cf.{+Variable}`
+
+:Examples 2:
+
+'''
+        if i:
+            c = self
+        else:
+            c = self.copy()
+
+        super(BoundedVariable, c).override_calendar(calendar, i=True)
+
+        if c.hasbounds:
+            c.bounds.override_calendar(calendar, i=True)
+
+        return c
+    #--- End: def
+
     def override_units(self, new_units, i=False):
         '''
 
@@ -1796,7 +1843,7 @@ keyword. Bounds may also be inserted independently with the
 
         super(BoundedVariable, c).override_units(new_units, i=True)
 
-        if c._hasbounds:
+        if c.hasbounds:
             c.bounds.override_units(new_units, i=True)
 
         if c._period is not None:
