@@ -1009,12 +1009,18 @@ Create a field for a given netCDF variable.
                 dimension_coordinates[ncdim] = coord
             #--- End: if
             
+            axis = DomainAxis(coord.size)
+            axis.ncdim = ncdim
+            if _debug:
+                print '    Inserting', repr(axis)
+            dim = f.insert_axis(axis)
+
             if _debug:
                 print '    Inserting', repr(coord)
-            dim = f.insert_dim(coord, copy=False)
-            # Record the netCDF dimension name for this axis
-#            f.Axes[dim].ncdim = ncdim
-            f.axes()[dim].ncdim = ncdim
+            dim = f.insert_dim(coord, axes=[dim], copy=False)
+#            # Record the netCDF dimension name for this axis
+##            f.Axes[dim].ncdim = ncdim
+#            f.axes()[dim].ncdim = ncdim
 
             # Set unlimited status of axis
             if nc.dimensions[ncdim].isunlimited():
@@ -1107,9 +1113,7 @@ Create a field for a given netCDF variable.
                     if _debug:
                         print '    Inserting', repr(axis)
                     dim = f.insert_axis(axis)
-                    # Record the netCDF dimension name for this axis
-#                    f.Axes[dim].ncdim = ncdim                    
-                    f.axes()[dim].ncdim = ncdim
+
                     dimensions = [dim]
                 else:  
                     # Numeric valued scalar coordinate
@@ -1119,12 +1123,15 @@ Create a field for a given netCDF variable.
             if is_dimension_coordinate:
                 # Insert dimension coordinate
                 coord = coord.asdimension(copy=False)
+                axis = DomainAxis(1)
+                if _debug:
+                    print '    Inserting', repr(axis)
+                dim = f.insert_axis(axis)
+                
                 if _debug:
                     print '    Inserting', repr(coord)
-                dim = f.insert_dim(coord, copy=False)
-                # Record the netCDF dimension name for this axis
-#                f.Axes[dim].ncdim = ncvar
-                f.axes()[dim].ncdim = ncvar
+                dim = f.insert_dim(coord, axes=[dim], copy=False)
+                
                 dimensions = [dim]
                 ncvar_to_key[ncvar] = dim
                 dimension_coordinates[ncvar] = coord
@@ -1134,6 +1141,7 @@ Create a field for a given netCDF variable.
                 if _debug:
                     print '    Inserting', repr(coord)
                 aux = f.insert_aux(coord, axes=dimensions, copy=False)
+                
                 ncvar_to_key[ncvar] = aux
             
             if scalar:
