@@ -667,10 +667,21 @@ array([-31., -30., -29., -28., -27.])
         to `ut_parse` function of Udunits. Ignored if `units` is set.
 
 '''
+        self._isvalid = True
+        
         if isinstance(units, self.__class__):
             self.__dict__ = units.__dict__
             return
 
+        # Set the calendar
+        _calendar = None
+        if calendar is not None:
+            _calendar = _canonical_calendar.get(calendar.lower())
+            if _calendar is None:
+                self._isvalid = False
+                _calendar = calendar
+        #--- End: if
+        
         if units is not None:
             try:
                 units = units.strip()
@@ -689,16 +700,26 @@ array([-31., -30., -29., -28., -27.])
 
                 units_split = units.split(' since ')
                 unit        = units_split[0].strip()
-
+                
                 ut_unit = _cached_ut_unit.get(unit, None)
                 if ut_unit is None:                    
                     ut_unit = _ut_parse(_ut_system, _c_char_p(unit), _UT_ASCII)
                     if not ut_unit or not _ut_are_convertible(ut_unit, _day_ut_unit):
-                        raise ValueError(
-                            "Can't set unsupported unit in reference time: '%s'" % 
-                            value)
-                    _cached_ut_unit[unit] = ut_unit
+                        ut_unit = None
+                        self._isvalid = False
+                    else:
+                        _cached_ut_unit[unit] = ut_unit
                 #--- End: if
+                
+#                ut_unit = _cached_ut_unit.get(unit, None)
+#                if ut_unit is None:                    
+#                    ut_unit = _ut_parse(_ut_system, _c_char_p(unit), _UT_ASCII)
+#                    if not ut_unit or not _ut_are_convertible(ut_unit, _day_ut_unit):
+#                        raise ValueError(
+#                            "Can't set unsupported unit in reference time: '%s'" % 
+#                            value)
+#                    _cached_ut_unit[unit] = ut_unit
+#                #--- End: if
 
                 utime = _cached_utime.get((_calendar, units), None)
 
@@ -743,10 +764,19 @@ array([-31., -30., -29., -28., -27.])
                 if ut_unit is None:
                     ut_unit = _ut_parse(_ut_system, _c_char_p(units), _UT_ASCII)
                     if not ut_unit:
-                        raise ValueError(
-                            "Can't set unsupported unit: %r" % units)
-                    _cached_ut_unit[units] = ut_unit
+                        ut_unit = None
+                        self._isvalid = False
+                    else:
+                        _cached_ut_unit[units] = ut_unit
                 #--- End: if
+ 
+#                if ut_unit is None:
+#                    ut_unit = _ut_parse(_ut_system, _c_char_p(units), _UT_ASCII)
+#                    if not ut_unit:
+#                        raise ValueError(
+#                            "Can't set unsupported unit: %r" % units)
+#                    _cached_ut_unit[units] = ut_unit
+#                #--- End: if
 
                 self._isreftime = False
                 self._calendar  = None
@@ -1589,7 +1619,23 @@ False
 
         return bool(_ut_are_convertible(ut_unit, _day_ut_unit))
     #--- End: def
-
+        ut_unit = self._ut_unit
+        if ut_unit is None:
+            return False
+ 
+        return bool(_ut_are_convertible(ut_unit, _day_ut_unit))
+    #--- End: def
+ 
+    # ----------------------------------------------------------------
+    # Attribute (read only)
+    # ----------------------------------------------------------------
+    @property
+    def isvalid(self):
+        '''
+        '''
+        return getattr(self, '_isvalid', False)
+    #--- End: def
+    
     # ----------------------------------------------------------------
     # Attribute (read only)
     # ----------------------------------------------------------------
